BlackDog
========

BlackDog is a local webservice that maps bukkitdev plugins to a maven repository structure.

It is a delicious cocktail made with [Tequila][tequila].

## Installation

### Prerequisites

* [Python 3][python]

### With the package manager (recommended)

From an elevated shell, run `pip install blackdog`.

### From the source code

From an elevated shell, run `pip install -e git+https://github.com/Snaipe/BlackDog.git#egg=blackdog`.

You may check if BlackDog is installed by running `blackdog -h`.

[python]: https://www.python.org/
[tequila]: https://github.com/Snaipe/Tequila
